@@ -4,10 +4,20 @@ import statsd
 
 
 class Timer(statsd.Client):
-    '''Statsd Timer Object
+    '''
+    Statsd Timer Object
 
-    Additional documentation is available at the
-    parent class :class:`~statsd.client.Client`
+    Additional documentation is available at the parent class
+    :class:`~statsd.client.Client`
+
+    :keyword name: The name for this timer
+    :type name: str
+    :keyword connection: The connection to use, will be automatically created if
+        not given
+    :type connection: :class:`~statsd.connection.Connection`
+    :keyword min_send_threshold: Timings smaller than this will not be sent so -1
+        can be used for all.
+    :type min_send_threshold: int
 
     >>> timer = Timer('application_name')
     >>> timer.start()
@@ -16,11 +26,12 @@ class Timer(statsd.Client):
     True
     '''
 
-    def __init__(self, name, connection=None):
+    def __init__(self, name, connection=None, min_send_threshold=-1):
         super(Timer, self).__init__(name, connection=connection)
         self._start = None
         self._last = None
         self._stop = None
+        self.min_send_threshold = min_send_threshold
 
     def start(self):
         '''Start the timer and store the start time, this can only be executed
@@ -34,18 +45,24 @@ class Timer(statsd.Client):
 
         :keyword subname: The subname to report the data to (appended to the
             client name)
+        :type subname: str
         :keyword delta: The time delta (time.time() - time.time()) to report
+        :type delta: float
         '''
         ms = delta * 1000
-        name = self._get_name(self.name, subname)
-        self.logger.info('%s: %0.08fms', name, ms)
-        return statsd.Client._send(self, {name: '%0.08f|ms' % ms})
+        if ms > self.min_send_threshold:
+            name = self._get_name(self.name, subname)
+            self.logger.info('%s: %0.08fms', name, ms)
+            return statsd.Client._send(self, {name: '%0.08f|ms' % ms})
+        else:
+            return True
 
     def intermediate(self, subname):
         '''Send the time that has passed since our last measurement
 
         :keyword subname: The subname to report the data to (appended to the
             client name)
+        :type subname: str
         '''
         t = time.time()
         response = self.send(subname, t - self._last)
@@ -57,6 +74,7 @@ class Timer(statsd.Client):
 
         :keyword subname: The subname to report the data to (appended to the
             client name)
+        :type subname: str
         '''
         assert self._stop is None, (
             'Unable to stop, the timer is already stopped')
@@ -95,7 +113,7 @@ class Timer(statsd.Client):
         ...     pass
         >>>
         >>> @timer.decorate('my_timer')
-        ... def some_function():
+        ... def some_other_function():
         ...     # resulting timer name: application_name.my_timer
         ...     pass
 
@@ -110,7 +128,11 @@ class Timer(statsd.Client):
         '''Returns a context manager to time execution of a block of code.
 
         :keyword subname: The subname to report data to
-        :keyword class_: The class to use as a client
+        :type subname: str
+        :keyword class_: The :class:`~statsd.client.Client` subclass to use
+            (e.g. :class:`~statsd.timer.Timer` or
+            :class:`~statsd.counter.Counter`)
+        :type class_: :class:`~statsd.client.Client`
 
         >>> from statsd import Timer
         >>> timer = Timer('application_name')
